@@ -15,7 +15,7 @@ class ModeRageClient():
     def _get_experiment_cache_location(self, id, meta_category):
         return self._get_meta_category_cache_location(meta_category).joinpath(id)
 
-    def save(self, meta_category, meta, parents=None, files=None, keep_originals=False):
+    def save(self, meta_category, meta, started_timestamp, ended_timestamp, git_tag=None, parents=None, files=None, keep_originals=False):
         raise NotImplementedError()
 
     def load(self, id, meta_category, ignore_files=False):
